# BomberNight
 Bomberman, porém com uma temática dark

## Instalação
` $ pip3 install BomberNight `


## Como jogar
Para iniciar o jogo, digite:
` $ bombernight `

## Controles
Para movimentar o player, use as teclas:
- w ou cima 
- s ou baixo 
- a ou esquerda
- d ou direita
- espaço para colocar uma bomba